from libqtile import bar, layout, widget
from libqtile.config import Click, Drag, Group, Key, Match, Screen
from libqtile.lazy import lazy

mod = "mod4"
terminal = "alacritty"
browser = "firefox"
run_prompt = "dmenu_run"


# colors
accent  = "#ea6962"
accent2 = "#d8a657"
bg_col  = "#282828"
fg_col  = "#d4be98"

# custom functions
def SplitString(string):
    return list(string.split(" "))

keys = [
    Key([mod], "j",
        lazy.layout.down(),
        desc="Move focus down"),
    Key([mod], "k",
        lazy.layout.up(),
        desc="Move focus up"),

    Key([mod, "shift"], "j",
        lazy.layout.shuffle_down(),
        desc="Move window down"),
    Key([mod, "shift"], "k",
        lazy.layout.shuffle_up(),
        desc="Move window up"),

    Key([mod], "h",
        lazy.layout.grow(),
        desc="Grow window to the left"),
    Key([mod], "l",
        lazy.layout.shrink(),
        desc="Grow window to the right"),
    Key([mod], "n",
        lazy.layout.normalize(),
        desc="Reset all window sizes"),

    Key([mod], "Return",
        lazy.spawn(terminal),
        desc="Launch terminal"),
    Key([mod], "b",
        lazy.spawn(browser),
        desc="Launch browser"),
    Key([mod], "r",
        lazy.spawn(run_prompt),
        desc="Spawn a command using a prompt widget"),
    Key([mod], "p",
        lazy.spawn("screenshotit"),
        desc="Literally a screenshot utility, wow"),
    Key([mod, "shift"], "s",
        lazy.spawn("shorten-clipb"),
        desc="Shortens a url (via 0.vern.cc) that's on the clipboard"),

    Key([mod], "space",
        lazy.next_layout(),
        desc="Toggle between layouts"),
    Key([mod], "w",
        lazy.window.kill(),
        desc="Kill focused window"),
    Key([mod, "shift"], "r",
        lazy.reload_config(),
        desc="Reload the config"),
    Key([mod, "shift"], "q",
        lazy.shutdown(),
        desc="Shutdown Qtile"),
]

groups = [Group(i) for i in "123456789"]

for i in groups:
    keys.extend(
        [
            # mod1 + letter of group = switch to group
            Key(
                [mod],
                i.name,
                lazy.group[i.name].toscreen(),
                desc="Switch to group {}".format(i.name),
            ),
            # mod1 + shift + letter of group = switch to & move focused window to group
            Key(
                [mod, "shift"],
                i.name,
                lazy.window.togroup(i.name, switch_group=True),
                desc="Switch to & move focused window to group {}".format(i.name),
            ),
            # Or, use below if you prefer not to switch to that group.
            # # mod1 + shift + letter of group = move focused window to group
            # Key([mod, "shift"], i.name, lazy.window.togroup(i.name),
            #     desc="move focused window to group {}".format(i.name)),
        ]
    )

layouts = [
    layout.MonadTall(border_focus = accent,
                     border_unfocus = "#222222",
                     border_width = 1,
                     margin = 2),
    layout.Max(),
]

widget_defaults = dict(
    font       = "monospace",
    fontsize   = 12,
    padding    = 3,
    background = bg_col,
    foreground = fg_col,
)

screens = [
    Screen(
        top=bar.Bar(
            [
                widget.CurrentLayoutIcon(scale=0.8, custom_icon_paths="~/.config/qtile/icons"),
                widget.GroupBox(rounded=False, highlight_method="block", active=fg_col, inactive=fg_col, urgent_border=accent2, this_current_screen_border=accent),
                #widget.WindowName(),
                widget.Spacer(length=bar.STRETCH),
                widget.Chord(
                    chords_colors={
                        "launch": ("#ff0000", "#ffffff"),
                    },
                    name_transform=lambda name: name.upper(),
                ),
                # widget.StatusNotifier(),
                widget.Systray(),
                widget.Clock(format="%Y-%m-%d %a %I:%M %p"),
            ],
            24,
            # border_width=[2, 0, 2, 0],  # Draw top and bottom borders
            # border_color=["ff00ff", "000000", "ff00ff", "000000"]  # Borders are magenta
        ),
    ),
]

# Drag floating layouts.
mouse = [
    Drag([mod], "Button1", lazy.window.set_position_floating(), start=lazy.window.get_position()),
    Drag([mod], "Button3", lazy.window.set_size_floating(), start=lazy.window.get_size()),
    Click([mod], "Button2", lazy.window.toggle_floating())
]

dgroups_key_binder = None
dgroups_app_rules = []  # type: list
follow_mouse_focus = True
bring_front_click = False
cursor_warp = False
floating_layout = layout.Floating(
    float_rules=[
        # Run the utility of `xprop` to see the wm class and name of an X client.
        *layout.Floating.default_float_rules,
        Match(wm_class="confirmreset"),  # gitk
        Match(wm_class="makebranch"),  # gitk
        Match(wm_class="maketag"),  # gitk
        Match(wm_class="ssh-askpass"),  # ssh-askpass
        Match(title="branchdialog"),  # gitk
        Match(title="pinentry"),  # GPG key password entry
    ]
)
auto_fullscreen = True
focus_on_window_activation = "smart"
reconfigure_screens = True

auto_minimize = False

wl_input_rules = None

wmname = "LG3D"
